@@ -20,8 +20,6 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
-
 """
 Geography for two families
 """
@@ -148,6 +146,7 @@ class GeoFamClose(GeoGraphyView):
         self.minyear = 9999
         self.maxyear = 0
         self.reffamily = None
+        self.reffamily_bookmark = None
         self.nbplaces = 0
         self.nbmarkers = 0
         self.sort = []
@@ -194,17 +193,6 @@ class GeoFamClose(GeoGraphyView):
         """
         return 'Family'
 
-    def add_bookmark(self, obj):
-        mlist = self.selected_handles()
-        if mlist:
-            self.bookmarks.add(mlist[0])
-        else:
-            from gramps.gui.dialog import WarningDialog
-            WarningDialog(
-                _("Could Not Set a Bookmark"), 
-                _("A bookmark could not be set because "
-                  "no one was selected."))
-
     def family_label(self,family):
         if family is None:
             return "Unknown"
@@ -258,11 +246,14 @@ class GeoFamClose(GeoGraphyView):
         if self.reffamily:
             color = self._config.get('geography.color1')
             self._createmap(self.reffamily, color, self.place_list_ref, True)
-            self.message_layer.add_message(_("Family reference : %s") % self.family_label(self.reffamily))
+            self.message_layer.add_message(_("Family reference : %s" % self.family_label(self.reffamily)))
             if f1:
-                self.message_layer.add_message(_("The other family : %s") % self.family_label(f1))
+                self.message_layer.add_message(_("The other family : %s" % self.family_label(f1)))
             else:
-                self.message_layer.add_message(_("The other family : %s") % _("Unknown"))
+                self.message_layer.add_message(_("The other family : %s" % _("Unknown")))
+            if self.reffamily_bookmark is None:
+                self.reffamily_bookmark = self.reffamily.get_handle()
+                self.add_bookmark(None, self.reffamily_bookmark)
         else:
             self.message_layer.add_message(_("You must choose one reference family."))
             self.message_layer.add_message(_("Go to the family view and select "
@@ -293,6 +284,8 @@ class GeoFamClose(GeoGraphyView):
         """
         self.track = []
         self.skip_list = []
+        self.ref_family = None
+        self.reffamily_bookmark = None
         selectFamily = SelectorFactory('Family')
         sel = selectFamily(self.dbstate, self.uistate)
         self.reffamily = sel.run()
@@ -696,7 +689,7 @@ class GeoFamClose(GeoGraphyView):
         add_item = Gtk.MenuItem()
         add_item.show()
         menu.append(add_item)
-        add_item = Gtk.MenuItem(label=_("Choose the reference family"))
+        add_item = Gtk.MenuItem(label=_("Choose and bookmark the new reference family"))
         add_item.connect("activate", self.selectFamily)
         add_item.show()
         menu.append(add_item)
@@ -714,7 +707,7 @@ class GeoFamClose(GeoGraphyView):
         Add specific entry to the preference menu.
         Must be done in the associated view.
         """
-        table = Gtk.Table(2, 2)
+        table = Gtk.Table(n_rows=2, n_columns=2)
         table.set_border_width(12)
         table.set_col_spacings(6)
         table.set_row_spacings(6)
